// 名前空間
var ARCHIVE_UI = {};

document.addEventListener("DOMContentLoaded", function () {
  // アーカイブ検索
  bindArchiveSearch();
  // iOSキーボード変換検知用
  bindiOSKeyBoardEvent();
});

ARCHIVE_UI.refreshSearchScreen = function (keyword) {
  const archiveList = NativeBridgeDataSource.getArchiveByName(keyword);
  const typeImage = getArchiveTypeIconURL(archive.archiveType);

  getArchiveTemplate().then(function (archiveTemplate) {
    archiveList.forEach(function (archive) {
      let html = renderArchiveTemplate(
        archiveTemplate,
        archive.archiveId,
        archive.archiveName,
        archive.archiveDate,
        typeImage
      );

      let obj = jQuery.parseHTML(html);
      $(".overlay_src_msg").append(obj);
    });
  });
};

//* UTILS *//
const ARCHIVE_TYPE = {
  PICTURE: 0,
  VIDEO: 1,
  VOICE: 2,
  DOCUMENT: 3,
};

var getArchiveTypeIconURL = function (type) {
  switch (type) {
    case ARCHIVE_TYPE.PICTURE:
      return "icon/icon_collabo_picture.png";
    case ARCHIVE_TYPE.VIDEO:
      return "icon/icon_collabo_videocam.png";
    case ARCHIVE_TYPE.VOICE:
      return "icon/icon_collabo_headset.png";
    case ARCHIVE_TYPE.DOCUMENT:
      return "icon/icon_collabo_document.png";
    default:
      return "";
  }
};

var getArchiveTemplate = function () {
  return new Promise(function (resolve, reject) {
    $.get({ url: TemplateURL.ARCHIVE_LIST, async: false }, function (text) {
      resolve(text);
    });
  });
};

var bindArchiveSearch = function () {
  const searchInput = $('#archive .search_form input[type="search"]');
  searchInput.keyup(function (e) {
    var keyword = searchInput.val();
    const enterKeyPressed = e.KeyCode == 13 || e.key == "Enter";
    const keywordEmpty = keyword == "" || keyword.length < 2;
    const keywordNotEmpty = keyword.length != 0 && keyword != "";
    if (enterKeyPressed) {
      if (keywordNotEmpty) {
        searchInput.blur();
        return;
      }
    } else if (keywordEmpty) {
      $(".overlay_src_msg").empty();
      return;
    }
    $(".overlay_src_msg").empty();

    ARCHIVE_UI.refreshSearchScreen(keyword);

    if (enterKeyPressed) {
      searchInput.blur();
      return;
    }
    // 検索結果を表示
  });
};

var bindiOSKeyBoardEvent = function () {
  const searchInput = $('#archive .search_form input[type="search"]');
  searchInput.on("compositionend", function () {
    if (deviceInfo.isiOS()) {
      var keyword = searchInput.val();
      $(".overlay_src_msg").empty();
      ARCHIVE_UI.refreshSearchScreen(keyword);
    }
  });
};

var renderArchiveTemplate = function (
  html,
  archiveId,
  archiveName,
  archiveDate,
  typeImageURL
) {
  return Mustache.render(html, {
    archiveId: archiveId,
    fileName: archiveName,
    insertDate: archiveDate,
    typeImage: typeImageURL,
  });
};

// アーカイブ詳細
CHAT_UI.refreshArchiveDetailScreen = function (archiveId) {
  // loadingIndicatorを表示
  Common.showLoadingIndicator();

  // 初期化
  $("#archiveDetail").html("");

  // アーカイブ詳細の様式を読み込む
  const archiveDetailTemplate = $("#archive-detail-template").html();
  if (serverInfo.isOnline == "true") {
    NativeBridgeDelegate.updateArchiveDetail(archiveId);
  }
  // アーカイブ詳細取得
  const archive = NativeBridgeDataSource.getArchiveDetail(archiveId);

  // 保存ユーザ情報を取得
  const userInfo = NativeBridgeDataSource.getUserInfo(archive.saveUserId);
  userInfo.profileUrl = Common.getProfileImgUrl(userInfo.profileUrl);

  // アーカイブ情報を表示
  const html = Mustache.render(archiveDetailTemplate, {
    fileName: archive.archiveName,
    insertDate: archive.archiveDate,
    chatRoomName: archive.roomName,
    chatRoomId: archive.roomId,
    profileImage: userInfo.profileUrl,
    userName: userInfo.shopMemberName,
    userId: userInfo.shopMemberId,
  });

  var obj = $(jQuery.parseHTML(html)).on("click", function () {});
  $("#archiveDetail").append(obj);

  // プレイヤーの切り替え
  const archiveFilePath = CHAT.createGetDataUrl(
    archive.filePath,
    archive.roomId
  );

  switch (archive.archiveType) {
    case "0": // 画像
    case 0:
      $("#archive_player").prepend(
        '<img class="archive_player" src="' + archiveFilePath + '" />'
      );
      break;
    case "1": // 動画
    case 1:
      if (deviceInfo.isiOS()) {
        $("#archive_player").prepend(
          '<video class="archive_player" controls autoplay muted playsinline controlsList="nodownload"><source src="' +
            archiveFilePath +
            '" type="video/mp4"><source src="' +
            archiveFilePath +
            '" type="video/ogv"><source src="' +
            archiveFilePath +
            '" type="video/webm"></video>'
        );
      } else {
        $("#archive_player").prepend(
          '<video class="archive_player" src=' +
            archiveFilePath +
            ' controls autoplay muted playsinline controlsList="nodownload"></video>'
        );
      }
      break;
    case "2": // 音声
    case 2:
      if (deviceInfo.isiOS()) {
        $("#archive_player").prepend(
          '<audio class="archive_audio_player" controls controlsList="nodownload"><source src="' +
            archiveFilePath +
            '" type="audio/wav"><source src="' +
            archiveFilePath +
            '" type="audio/ogg"></audio>'
        );
      } else {
        $("#archive_player").prepend(
          '<audio class="archive_audio_player" src=' +
            archiveFilePath +
            ' controls controlsList="nodownload"></audio>'
        );
      }
      $("#archive_player").prepend(
        '<img class="archive_player" src=' + "./img/capture.png" + " />"
      );
      break;
    case "3": // 文書
    case 3:
      // リリースに文書とその他は含めないため今回は非表示
      break;
    default:
    // リリースに文書とその他は含めないため今回は非表示
  }

  // ユーザの様式を読み込む
  const archiveUserTemplate = $("#archive-user-template").html();

  // 参加ユーザ情報を表示
  let attendUserList = archive.attendUserIds;
  if (typeof android != "undefined") {
    // ios実装不要
    attendUserList = JSON.parse(archive.attendUserIds);
  }

  attendUserList.forEach(function (user) {
    if (user == "") {
      return;
    }
    var userInfo = NativeBridgeDataSource.getUserInfo(user);
    userInfo.profileUrl = Common.getProfileImgUrl(userInfo.profileUrl);
    const html = Mustache.render(archiveUserTemplate, {
      profileImage: userInfo.profileUrl,
      userName: userInfo.shopMemberName,
    });

    const obj = $(jQuery.parseHTML(html)).on("click", function () {
      // ネームカード表示
      CHAT_UI.makeNameCard(user);
    });

    $("#attendUser").append(obj);
  });

  currentUserInfo.configureLanguage();
  // TODO: peacekim:: check localization works or not
  $(".ttl_detail").text(getLocalizedString("detail"));
  $("#archiveFileName").text(getLocalizedString("archiveFileName"));
  $("#archiveInsertDate").text(getLocalizedString("archiveInsertDate"));
  $("#archiveRoomName").text(getLocalizedString("archiveRoomName"));
  $("#archiveSaveUser").text(getLocalizedString("archiveSaveUser"));
  $("#archiveAttendUser").text(getLocalizedString("archiveAttendUser"));

  // チャットルームへのリンク付け
  document.getElementById("joinChatRoom").onclick = function () {
    NativeBridgeDelegate.joinRoom(archive.roomId, archive.roomName);
  };

  // loadingIndicatorを非表示
  Common.dismissLoadingIndicator();
};

CHAT.createGetDataUrl = function (fileName, roomId) {
  var filePath =
    serverInfo.cmsURL +
    "/chatapi/file/getImage?sid=" +
    currentUserInfo.sid +
    "&fileName=" +
    fileName +
    "&roomId=" +
    roomId;
  return filePath;
};

// アーカイブ一覧
CHAT_UI.refreshArchiveScreen = function () {
  // loadingIndicatorを表示
  Common.showLoadingIndicator();

  // 初期化
  $("#archiveList").html("");

  // アーカイブの様式を読み込む
  const archiveTemplate = $("#archive-template").html();

  // アーカイブ一覧取得
  if (serverInfo.isOnline == "true") {
    NativeBridgeDelegate.updateArchiveList();
  }

  // ローカルDBのデータを表示
  var archiveList = NativeBridgeDataSource.getArchiveList();
  if (typeof archiveList == "undefined") {
    Common.dismissLoadingIndicator();
    return;
  }
  archiveList.forEach(function (archive) {
    var typeImage = "";
    switch (archive.archiveType) {
      case 0: // 画像
        typeImage = "icon/icon_collabo_picture.png";
        break;
      case 1: // 動画
        typeImage = "icon/icon_collabo_videocam.png";
        break;
      case 2: // 音声
        typeImage = "icon/icon_collabo_headset.png";
        break;
      case 3: // 文書
        typeImage = "icon/icon_collabo_document.png";
        break;
      default:
        // その他
        typeImage = "";
    }
    let html = Mustache.render(archiveTemplate, {
      archiveId: archive.archiveId,
      fileName: archive.archiveName,
      insertDate: archive.archiveDate,
      typeImage: typeImage,
    });
    let obj = $(jQuery.parseHTML(html)).on("click", function () {});
    $("#archiveList").append(obj);
  });

  // loadingIndicatorを非表示
  Common.dismissLoadingIndicator();
};
